@@ -5,17 +5,20 @@ import logging
 import requests
 from pydrive.auth import GoogleAuth
 from pydrive.drive import GoogleDrive
-from decouple import config
+# from decouple import config
+from dotenv import load_dotenv
+import os
 
-apiKey = config('monday_apikey')
-apiUrl = "https://api.monday.com/v2"
+load_dotenv(os.getcwd() +'/.env')
+
+apiKey = os.environ.get('monday_apikey')
+apiUrl = os.environ.get('API_URL')
 headers = {"Authorization": apiKey, "Content-Type ": "application/json"}
 
-
 def GetBoardFromGitlab():  # for getting repository information
     logging.info('This is in GetBoardFromGitlab function')
-    url = config('gitlab_url')
-    token = config('gitlab_token')
+    url = os.environ.get('gitlab_url')
+    token = os.environ.get('gitlab_token')
     headers1 = {"Authorization": token}
     r = requests.get(url=url, headers=headers1)
     jsondata = r.json()
@@ -40,7 +43,6 @@ def GetBoardIds():  # for Getting each board id
     r = requests.post(url=apiUrl, json=data1, headers=headers)
     data = r.json()
     data = data['data']
-    print(data['boards'])
     board_ids = []
     for i in data['boards']:
         board_ids.append(i['id'])
@@ -60,7 +62,7 @@ def GetBoardItem(board_ids, apiUrl, headers):  # for getting all items of pertic
 
 
 def ValidateCoulmnData(data):  # for getting not validate item of board
-    test_board_id = config('test_board_id')
+    test_board_id = os.environ.get('test_board_id')
     status_option = ["In progress", "Done", "Stuck", "", "", "Not Defined"]
     itemdata = data['data']
     items = {}
@@ -140,22 +142,83 @@ def ValidateCoulmnData(data):  # for getting not validate item of board
 
 
 def CreateFile(name):  # for create item if created document name is not valid
-    non_conformance_id = config('non_conformance_id')
+    non_conformance_id = os.environ.get('non_conformance_id')
     gauth = GoogleAuth()
     gauth.LocalWebserverAuth()
     drive = GoogleDrive(gauth)
 
+    flat_folder_list = ['Abstracts',
+                        'Data Partners',
+                        'Documentation',
+                        'Manuscripts',
+                        'Outputs',
+                        'Posters',
+                        'Presentations',
+                        'References',
+                        'Reports',
+                        'Test Slide Deck.pptx',
+                        'Test Study Protocol.pdf'
+                        ]
+
     folder_list = []
-    # get all folder name
-    f = drive.ListFile({"q": "mimeType='application/vnd.google-apps.folder' and trashed=false"}).GetList()
-    for folder in f:
-        folder_list.append(folder['title'])
+
+    flag = 'modular'
+    if flag == 'flat':
+        # get all folder name
+        f = drive.ListFile({"q": "mimeType='application/vnd.google-apps.folder' or mimeType='applicationvnd.google-apps.folder' and trashed=false"}).GetList()
+        for folder in f:
+            folder_list.append(folder['title'])
+        for name in flat_folder_list:
+            # Create folder
+
+            if name not in folder_list:
+                # Create folder
+                folder_metadata = {'title': name, 'mimeType': 'applicationvnd.google-apps.folder'}
+                if name.endswith('.pptx') or name.endswith('.pdf'):
+                    folder = drive.CreateFile(folder_metadata)
+                    folder.Upload()
+                else:
+                    folder = drive.CreateFile({'title': name, 'mimeType': 'application/vnd.google-apps.folder'})
+                    folder.Upload()
+    if flag == 'modular':
+        module_name = ['module_A', 'module_B', 'Test Slide Deck.pptx', 'Test Study Protocol.pdf']
+        module_folder_inside_structure = ['Abstracts',
+                                          'Data Partners',
+                                          'Documentation',
+                                          'Manuscripts',
+                                          'Outputs',
+                                          'Posters',
+                                          'Presentations',
+                                          'References',
+                                          'Reports'
+                                          ]
+        module_name_list = []
+        module_id = []
+        # get all folder name
+        f = drive.ListFile({
+                               "q": "mimeType='application/vnd.google-apps.folder' or mimeType='applicationvnd.google-apps.folder'  and trashed=false"}).GetList()
+        for folder in f:
+            module_name_list.append(folder['title'])
+            module_id.append(folder['id'])
+
+        for m_name in module_name:
+            if m_name not in module_name_list:
+                parent_folder = drive.CreateFile({'title': m_name, 'mimeType': 'applicationvnd.google-apps.folder'})
+                if m_name.endswith('.pptx') or m_name.endswith('.pdf'):
+                    folder = drive.CreateFile(parent_folder)
+                    folder.Upload()
+
+                else:
+                    folder = drive.CreateFile({'title': m_name, 'mimeType': 'application/vnd.google-apps.folder'})
+                    folder.Upload()
+
+        for flat_name in module_folder_inside_structure:
+            for module_id in module_id:
+                if flat_name not in module_name_list or module_id not in module_id:
+                    folder_metadata = drive.CreateFile({'title': flat_name, "parents": [{'id': module_id}],
+                                                        'mimeType': 'application/vnd.google-apps.folder'})
+                    folder_metadata.Upload()
 
-    if name not in folder_list:
-        # Create folder
-        folder_metadata = {'title': name, 'mimeType': 'application/vnd.google-apps.folder'}
-        folder = drive.CreateFile(folder_metadata)
-        folder.Upload()
 
     # Get folder info and print to screen
     foldertitle = folder['title']
